==> estateplat-common-1.2.3-20190419.005626-236-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJfmx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产缴费明细
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/3/15
 */
@Table(name = "BDC_JFMX")
public class BdcJfmx {
    //缴费明细id
    @Id
    private String jfmxid;
    //缴费状态
    private String jfzt;
    //缴费描述
    private String jfms;
    //缴费类型
    private String jflx;
    //商户名称
    private String shmc;
    //商户编号
    private String shbh;
    //终端编号
    private String zdbh;
    //缴费卡号
    private String jfkh;
    //缴费批次号
    private String jfpch;
    //原缴费批次号
    private String yjfpch;
    //缴费凭证号
    private String jfpzh;
    //原缴费凭证号
    private String yjfpzh;
    //银行记账日期
    private Date yhjzrq;
    //缴费日期
    private Date jfrq;
    //缴费时间
    private Date jfsj;
    //缴费金额
    private Double jfje;
    //卡类型
    private String klx;
    //发卡组织名称
    private String fkzzmc;
    //订单号
    private String ddh;
    //缴费参考号
    private String jfckh;
    //实际缴费类型
    private String sjjflx;
    //收费信息结果表主键
    private String sfxxjdig;
    //业务受理编号
    private String ywslbh;
    //请求方缴费类型
    private String qqfjflx;
    //请求方商户名称
    private String qqfshmc;
    //请求方缴费金额
    private Double qqfjfje;
    //原缴费参考号
    private String yjfckh;
    //原缴费日期
    private Date yjfrq;

    public String getJfmxid() {
        return jfmxid;
    }

    public void setJfmxid(String jfmxid) {
        this.jfmxid = jfmxid;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getJfms() {
        return jfms;
    }

    public void setJfms(String jfms) {
        this.jfms = jfms;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getShmc() {
        return shmc;
    }

    public void setShmc(String shmc) {
        this.shmc = shmc;
    }

    public String getShbh() {
        return shbh;
    }

    public void setShbh(String shbh) {
        this.shbh = shbh;
    }

    public String getZdbh() {
        return zdbh;
    }

    public void setZdbh(String zdbh) {
        this.zdbh = zdbh;
    }

    public String getJfkh() {
        return jfkh;
    }

    public void setJfkh(String jfkh) {
        this.jfkh = jfkh;
    }

    public String getJfpch() {
        return jfpch;
    }

    public void setJfpch(String jfpch) {
        this.jfpch = jfpch;
    }

    public String getYjfpch() {
        return yjfpch;
    }

    public void setYjfpch(String yjfpch) {
        this.yjfpch = yjfpch;
    }

    public String getJfpzh() {
        return jfpzh;
    }

    public void setJfpzh(String jfpzh) {
        this.jfpzh = jfpzh;
    }

    public String getYjfpzh() {
        return yjfpzh;
    }

    public void setYjfpzh(String yjfpzh) {
        this.yjfpzh = yjfpzh;
    }

    public Date getYhjzrq() {
        return yhjzrq;
    }

    public void setYhjzrq(Date yhjzrq) {
        this.yhjzrq = yhjzrq;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public Double getJfje() {
        return jfje;
    }

    public void setJfje(Double jfje) {
        this.jfje = jfje;
    }

    public String getKlx() {
        return klx;
    }

    public void setKlx(String klx) {
        this.klx = klx;
    }

    public String getFkzzmc() {
        return fkzzmc;
    }

    public void setFkzzmc(String fkzzmc) {
        this.fkzzmc = fkzzmc;
    }

    public String getDdh() {
        return ddh;
    }

    public void setDdh(String ddh) {
        this.ddh = ddh;
    }

    public String getJfckh() {
        return jfckh;
    }

    public void setJfckh(String jfckh) {
        this.jfckh = jfckh;
    }

    public String getSjjflx() {
        return sjjflx;
    }

    public void setSjjflx(String sjjflx) {
        this.sjjflx = sjjflx;
    }

    public String getSfxxjdig() {
        return sfxxjdig;
    }

    public void setSfxxjdig(String sfxxjdig) {
        this.sfxxjdig = sfxxjdig;
    }

    public String getYwslbh() {
        return ywslbh;
    }

    public void setYwslbh(String ywslbh) {
        this.ywslbh = ywslbh;
    }

    public String getQqfjflx() {
        return qqfjflx;
    }

    public void setQqfjflx(String qqfjflx) {
        this.qqfjflx = qqfjflx;
    }

    public String getQqfshmc() {
        return qqfshmc;
    }

    public void setQqfshmc(String qqfshmc) {
        this.qqfshmc = qqfshmc;
    }

    public Double getQqfjfje() {
        return qqfjfje;
    }

    public void setQqfjfje(Double qqfjfje) {
        this.qqfjfje = qqfjfje;
    }

    public String getYjfckh() {
        return yjfckh;
    }

    public void setYjfckh(String yjfckh) {
        this.yjfckh = yjfckh;
    }

    public Date getYjfrq() {
        return yjfrq;
    }

    public void setYjfrq(Date yjfrq) {
        this.yjfrq = yjfrq;
    }
}

==> estateplat-common-1.2.4-20210120.013342-629-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJfmx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * 不动产缴费明细
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/3/15
 */
@Table(name = "BDC_JFMX")
public class BdcJfmx {
    //缴费明细id
    @Id
    private String jfmxid;
    //缴费状态
    private String jfzt;
    //缴费描述
    private String jfms;
    //缴费类型
    private String jflx;
    //商户名称
    private String shmc;
    //商户编号
    private String shbh;
    //终端编号
    private String zdbh;
    //缴费卡号
    private String jfkh;
    //缴费批次号
    private String jfpch;
    //原缴费批次号
    private String yjfpch;
    //缴费凭证号
    private String jfpzh;
    //原缴费凭证号
    private String yjfpzh;
    //银行记账日期
    private Date yhjzrq;
    //缴费日期
    private Date jfrq;
    //缴费时间
    private Date jfsj;
    //缴费金额
    private Double jfje;
    //卡类型
    private String klx;
    //发卡组织名称
    private String fkzzmc;
    //订单号
    private String ddh;
    //缴费参考号
    private String jfckh;
    //实际缴费类型
    private String sjjflx;
    //收费信息结果表主键
    private String sfxxjgid;
    //业务受理编号
    private String ywslbh;
    //请求方缴费类型
    private String qqfjflx;
    //请求方商户名称
    private String qqfshmc;
    //请求方缴费金额
    private Double qqfjfje;
    //原缴费参考号
    private String yjfckh;
    //原缴费日期
    private Date yjfrq;

    public String getJfmxid() {
        return jfmxid;
    }

    public void setJfmxid(String jfmxid) {
        this.jfmxid = jfmxid;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getJfms() {
        return jfms;
    }

    public void setJfms(String jfms) {
        this.jfms = jfms;
    }

    public String getJflx() {
        return jflx;
    }

    public void setJflx(String jflx) {
        this.jflx = jflx;
    }

    public String getShmc() {
        return shmc;
    }

    public void setShmc(String shmc) {
        this.shmc = shmc;
    }

    public String getShbh() {
        return shbh;
    }

    public void setShbh(String shbh) {
        this.shbh = shbh;
    }

    public String getZdbh() {
        return zdbh;
    }

    public void setZdbh(String zdbh) {
        this.zdbh = zdbh;
    }

    public String getJfkh() {
        return jfkh;
    }

    public void setJfkh(String jfkh) {
        this.jfkh = jfkh;
    }

    public String getJfpch() {
        return jfpch;
    }

    public void setJfpch(String jfpch) {
        this.jfpch = jfpch;
    }

    public String getYjfpch() {
        return yjfpch;
    }

    public void setYjfpch(String yjfpch) {
        this.yjfpch = yjfpch;
    }

    public String getJfpzh() {
        return jfpzh;
    }

    public void setJfpzh(String jfpzh) {
        this.jfpzh = jfpzh;
    }

    public String getYjfpzh() {
        return yjfpzh;
    }

    public void setYjfpzh(String yjfpzh) {
        this.yjfpzh = yjfpzh;
    }

    public Date getYhjzrq() {
        return yhjzrq;
    }

    public void setYhjzrq(Date yhjzrq) {
        this.yhjzrq = yhjzrq;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public Double getJfje() {
        return jfje;
    }

    public void setJfje(Double jfje) {
        this.jfje = jfje;
    }

    public String getKlx() {
        return klx;
    }

    public void setKlx(String klx) {
        this.klx = klx;
    }

    public String getFkzzmc() {
        return fkzzmc;
    }

    public void setFkzzmc(String fkzzmc) {
        this.fkzzmc = fkzzmc;
    }

    public String getDdh() {
        return ddh;
    }

    public void setDdh(String ddh) {
        this.ddh = ddh;
    }

    public String getJfckh() {
        return jfckh;
    }

    public void setJfckh(String jfckh) {
        this.jfckh = jfckh;
    }

    public String getSjjflx() {
        return sjjflx;
    }

    public void setSjjflx(String sjjflx) {
        this.sjjflx = sjjflx;
    }

    public String getSfxxjgid() {
        return sfxxjgid;
    }

    public void setSfxxjgid(String sfxxjdig) {
        this.sfxxjgid = sfxxjdig;
    }

    public String getYwslbh() {
        return ywslbh;
    }

    public void setYwslbh(String ywslbh) {
        this.ywslbh = ywslbh;
    }

    public String getQqfjflx() {
        return qqfjflx;
    }

    public void setQqfjflx(String qqfjflx) {
        this.qqfjflx = qqfjflx;
    }

    public String getQqfshmc() {
        return qqfshmc;
    }

    public void setQqfshmc(String qqfshmc) {
        this.qqfshmc = qqfshmc;
    }

    public Double getQqfjfje() {
        return qqfjfje;
    }

    public void setQqfjfje(Double qqfjfje) {
        this.qqfjfje = qqfjfje;
    }

    public String getYjfckh() {
        return yjfckh;
    }

    public void setYjfckh(String yjfckh) {
        this.yjfckh = yjfckh;
    }

    public Date getYjfrq() {
        return yjfrq;
    }

    public void setYjfrq(Date yjfrq) {
        this.yjfrq = yjfrq;
    }
}
